import { SentryError } from '@sentry/utils/error';
import { logger } from '@sentry/utils/logger';
import { NoopTransport } from './transports/noop';
/**
 * This is the base implemention of a Backend.
 * @hidden
 */
export class BaseBackend {
    /** Creates a new backend instance. */
    constructor(options) {
        this._options = options;
        if (!this._options.dsn) {
            logger.warn('No DSN provided, backend will not do anything.');
        }
        this._transport = this._setupTransport();
    }
    /**
     * Sets up the transport so it can be used later to send requests.
     */
    _setupTransport() {
        return new NoopTransport();
    }
    /**
     * @inheritDoc
     */
    eventFromException(_exception, _hint) {
        throw new SentryError('Backend has to implement `eventFromException` method');
    }
    /**
     * @inheritDoc
     */
    eventFromMessage(_message, _level, _hint) {
        throw new SentryError('Backend has to implement `eventFromMessage` method');
    }
    /**
     * @inheritDoc
     */
    sendEvent(event) {
        this._transport.sendEvent(event).catch(reason => {
            logger.error(`Error while sending event: ${reason}`);
        });
    }
    /**
     * @inheritDoc
     */
    getTransport() {
        return this._transport;
    }
}
//# sourceMappingURL=basebackend.js.map